@@ -14,6 +14,7 @@ from wrdice.util import *
 from wrdice.Army import Army
 from wrdice.Battle import Battle
 from wrdice.config import *
+import sys
 
 def start_sim(in_, out_):
     asyncio.run(Simulator(in_, out_))
@@ -24,8 +25,10 @@ def Simulator(q_in, q_out):
     while True:
         #n = q_in.coro_get()
         n = q_in.get()
-        if n is None:
-            return
+        print('.')
+        if n == 'EXIT':
+            print('exit')
+            sys.exit()
         else:
             # new simulation
             combat_system = n[0]
@@ -38,7 +41,7 @@ def Simulator(q_in, q_out):
 
 class Simulate:
     def __init__(self, army_a: Optional[Army], army_b: Optional[Army]):
-        self.N = 500
+        self.N = 2000
         self.army_a = army_a
         self.army_b = army_b
         self.battle_type = 'land'
@@ -116,8 +119,8 @@ class Simulate:
 
 
         for n in tqdm(range(self.N)):
-            battle = Battle(copy.deepcopy(self.army_a), 
-                            copy.deepcopy(self.army_b),
+            battle = Battle(copy.copy(self.army_a), 
+                            copy.copy(self.army_b),
                             config)
             status = battle.run(combat_system=combat_system)
             self.statistics.append(status)
